
# Environment variables
The following env variables should be set for complete testing of `flood`:
- `FLOOD_TEST_LOCAL_NODE_1`: example = `localhost:8545`
- `FLOOD_TEST_LOCAL_NODE_2`: example = `123.123.123.123:8888`
- `FLOOD_TEST_REMOTE_NODE_1`: example = `ubuntu@123.123.123.123:localhost:8545`
- `FLOOD_TEST_REMOTE_NODE_2`: example = `ubuntu@123.123.123.123:45.45.45.45:8545`

